@@ -104,6 +104,16 @@ class TestDeclaration:
 
         assert [c.name for c in CountryTable().columns] == ['system', 'population', 'foo', 'tld']
 
+    def test_columns_verbose_name(self):
+        """Tests that the model field's verbose_name is used for the column
+        """
+        class CountryTable(tables.ModelTable):
+            class Meta:
+                model = Country
+                columns = ('tld',)
+
+        assert [c.column.verbose_name for c in CountryTable().columns] == ['Domain Extension']
+
 
 def test_basic():
     """Some tests here are copied from ``test_basic.py`` but need to be
@@ -154,6 +164,18 @@ def test_basic():
     test_country_table(countries)
 
 
+def test_invalid_accessor():
+    """Test that a column being backed by a non-existent model property
+    is handled correctly.
+
+    Regression-Test: There used to be a NameError here.
+    """
+    class CountryTable(tables.ModelTable):
+        name = tables.Column(data='something-i-made-up')
+    countries = CountryTable(Country)
+    assert_raises(ValueError, countries[0].__getitem__, 'name')
+
+
 def test_caches():
     """Make sure the caches work for model tables as well (parts are
     reimplemented).
@@ -259,6 +281,7 @@ def test_callable():
     assert [row['example_domain'] for row in countries] == \
                     [row['null'] for row in countries]
 
+
 def test_relationships():
     """Test relationship spanning."""
 
@@ -338,4 +361,4 @@ def test_pagination():
     assert len(connection.queries)-start_querycount == 2
 
     # reset
-    settings.DEBUG = False
\ No newline at end of file
+    settings.DEBUG = False
